@@ -14,7 +14,6 @@
 
 #include <KIO/TransferJob>
 #include <KLocalizedString>
-#include <KUserFeedback/Provider>
 
 #include "backtracegenerator.h"
 #include "bugzillalib.h"
@@ -25,8 +24,12 @@
 #include "drkonqi_debug.h"
 #include "parser/backtraceparser.h"
 #include "productmapping.h"
+#include "sentryconnection.h"
+#include "settings.h"
 #include "systeminformation.h"
 
+using namespace std::chrono_literals;
+
 // Max size a report may have. This is enforced in bugzilla, hardcoded, and
 // cannot be queried through the API, so handle this client-side in a hardcoded
 // fashion as well.
@@ -35,6 +38,7 @@ static const int s_maxReportSize = 65535;
 ReportInterface::ReportInterface(QObject *parent)
     : QObject(parent)
     , m_duplicate(0)
+    , m_sentryPostbox(DrKonqi::crashedApplication()->fakeExecutableBaseName(), std::make_shared<SentryNetworkConnection>())
 {
     m_bugzillaManager = new BugzillaManager(KDE_BUGZILLA_URL, this);
 
@@ -50,21 +54,15 @@ ReportInterface::ReportInterface(QObject *parent)
     // Do not attach the bug report to any other existent report (create a new one)
     m_attachToBugNumber = 0;
 
-    connect(&m_sentryBeacon, &SentryBeacon::eventSent, this, [this] {
-        m_sentryEventSent = true;
+    connect(&m_sentryPostbox, &SentryPostbox::hasDeliveredChanged, this, [this] {
         maybeDone();
     });
-    connect(&m_sentryBeacon, &SentryBeacon::userFeedbackSent, this, [this] {
-        m_sentryUserFeedbackSent = true;
-        maybeDone();
-    });
-    if (KUserFeedback::Provider provider; provider.isEnabled() && provider.telemetryMode() == KUserFeedback::Provider::DetailedUsageStatistics
-        && !DrKonqi::isTestingBugzilla() && qgetenv("DRKONQI_KDE_BUGZILLA_URL").isEmpty() && !DrKonqi::crashedApplication()->hasDeletedFiles()) {
-        metaObject()->invokeMethod(this, [this] {
-            // Send crash event ASAP, if applicable. Trace quality doesn't matter for it.
-            sendCrashEvent();
-        });
-    }
+
+    m_sentryStartTimer.setInterval(5s);
+    m_sentryStartTimer.setSingleShot(true);
+    connect(&m_sentryStartTimer, &QTimer::timeout, this, &ReportInterface::trySentry);
+    connect(Settings::self(), &Settings::SentryChanged, &m_sentryStartTimer, QOverload<>::of(&QTimer::start));
+    trySentry();
 }
 
 void ReportInterface::setBugAwarenessPageData(bool rememberSituation, Reproducible reproducible, bool actions, bool unusual, bool configuration)
@@ -328,37 +326,35 @@ Bugzilla::NewBug ReportInterface::newBugReportTemplate() const
     return bug;
 }
 
-void ReportInterface::sendCrashEvent()
+void ReportInterface::prepareCrashEvent()
 {
-#if WITH_SENTRY
     if (DrKonqi::debuggerManager()->backtraceGenerator()->state() == BacktraceGenerator::Loaded) {
-        m_sentryBeacon.sendEvent();
+        m_sentryPostbox.addEventPayload(SentryEvent(DrKonqi::debuggerManager()->backtraceGenerator()->sentryPayload()));
+        maybePickUpPostbox();
         return;
     }
     static bool connected = false;
     if (!connected) {
         connected = true;
         connect(DrKonqi::debuggerManager()->backtraceGenerator(), &BacktraceGenerator::done, this, [this] {
-            m_sentryBeacon.sendEvent();
+            m_sentryPostbox.addEventPayload(SentryEvent(DrKonqi::debuggerManager()->backtraceGenerator()->sentryPayload()));
+            maybePickUpPostbox();
         });
     }
     if (DrKonqi::debuggerManager()->backtraceGenerator()->state() != BacktraceGenerator::Loading) {
         DrKonqi::debuggerManager()->backtraceGenerator()->start();
     }
-#endif
 }
 
-void ReportInterface::sendCrashComment()
+void ReportInterface::prepareCrashComment()
 {
-#if WITH_SENTRY
-    m_sentryBeacon.sendUserFeedback(m_reportTitle + QLatin1Char('\n') + m_reportDetailText + QLatin1Char('\n') + DrKonqi::kdeBugzillaURL()
+    m_sentryPostbox.addUserFeedback(m_reportTitle + QLatin1Char('\n') + m_reportDetailText + QLatin1Char('\n') + DrKonqi::kdeBugzillaURL()
                                     + QLatin1String("show_bug.cgi?id=%1").arg(QString::number(m_sentReport)));
-#endif
 }
 
 void ReportInterface::sendBugReport()
 {
-    sendCrashEvent();
+    prepareCrashEvent();
 
     if (m_attachToBugNumber > 0) {
         // We are going to attach the report to an existent one
@@ -391,13 +387,14 @@ void ReportInterface::sendBugReport()
         Q_ASSERT(!report.description.isEmpty());
 
         connect(m_bugzillaManager, &BugzillaManager::sendReportErrorInvalidValues, this, &ReportInterface::sendUsingDefaultProduct);
-        connect(m_bugzillaManager, &BugzillaManager::reportSent, this, [=](int bugId) {
+        connect(m_bugzillaManager, &BugzillaManager::reportSent, this, [this, attach](int bugId) {
             if (attach) {
                 m_attachToBugNumber = bugId;
                 attachBacktrace(QStringLiteral("DrKonqi auto-attaching complete backtrace."));
             } else {
                 m_sentReport = bugId;
-                sendCrashComment();
+                prepareCrashComment();
+                m_sentryPostbox.deliver();
                 maybeDone();
             }
         });
@@ -443,7 +440,8 @@ void ReportInterface::attachSent(int attachId)
 
     // The bug was attached, consider it "sent"
     m_sentReport = attachId;
-    sendCrashComment();
+    prepareCrashComment();
+    m_sentryPostbox.deliver();
     maybeDone();
 }
 
@@ -534,7 +532,62 @@ ProductMapping *ReportInterface::productMapping() const
 
 void ReportInterface::maybeDone()
 {
-    if (m_sentReport != 0 && m_sentryEventSent && m_sentryUserFeedbackSent) {
+    if (m_sentReport != 0 && m_sentryPostbox.hasDelivered()) {
         Q_EMIT done();
     }
 };
+
+ReportInterface *ReportInterface::self()
+{
+    static ReportInterface interface;
+    return &interface;
+}
+
+bool ReportInterface::hasCrashEventSent() const
+{
+    return !isCrashEventSendingEnabled() || m_sentryPostbox.hasDelivered();
+}
+
+bool ReportInterface::isCrashEventSendingEnabled() const
+{
+    qCDebug(DRKONQI_LOG) << "sentry:" << Settings::self()->sentry() //
+                         << "forceSentry:" << m_forceSentry //
+                         << "hasDeletedFiles:" << DrKonqi::crashedApplication()->hasDeletedFiles();
+    const auto enabled = Settings::self()->sentry() || m_forceSentry;
+    return enabled && !DrKonqi::crashedApplication()->hasDeletedFiles();
+}
+
+void ReportInterface::setSendWhenReady(bool send)
+{
+    m_sendWhenReady = send;
+    maybePickUpPostbox();
+}
+
+void ReportInterface::maybePickUpPostbox()
+{
+    qWarning() << Q_FUNC_INFO;
+    if (m_sendWhenReady && !m_sentryPostbox.hasDelivered() && m_sentryPostbox.isReadyToDeliver()) {
+        m_sentryPostbox.deliver();
+    }
+}
+void ReportInterface::sendSentryReport()
+{
+    m_forceSentry = true;
+    trySentry();
+    // sendWhenReady is set by the quit handling in main.cpp
+}
+
+void ReportInterface::trySentry()
+{
+    qCDebug(DRKONQI_LOG) << "trying sentry?" << isCrashEventSendingEnabled() << !m_tryingSentry;
+    if (isCrashEventSendingEnabled() && !m_tryingSentry) {
+        m_tryingSentry = true;
+        metaObject()->invokeMethod(this, [this] {
+            connect(&m_sentryPostbox, &SentryPostbox::hasDeliveredChanged, this, &ReportInterface::crashEventSent);
+            // Send crash event ASAP, if applicable. Trace quality doesn't matter for it.
+            prepareCrashEvent();
+        });
+    }
+}
+
+#include "moc_reportinterface.cpp"
