@@ -13,8 +13,9 @@
 
 #include <QObject>
 #include <QStringList>
+#include <QTimer>
 
-#include "sentrybeacon.h"
+#include "sentrypostbox.h"
 
 namespace Bugzilla
 {
@@ -44,6 +45,7 @@ class ReportInterface : public QObject
     Q_PROPERTY(uint duplicateId READ duplicateId WRITE setDuplicateId NOTIFY duplicateIdChanged)
 
     Q_PROPERTY(uint sentReport MEMBER m_sentReport NOTIFY done)
+    Q_PROPERTY(uint crashEventSent READ hasCrashEventSent NOTIFY crashEventSent)
 public:
     enum Reproducible {
         ReproducibleUnsure,
@@ -66,7 +68,8 @@ public:
     };
     Q_ENUM(DrKonqiStamp)
 
-    explicit ReportInterface(QObject *parent = nullptr);
+    static ReportInterface *self();
+
     Q_SIGNAL void awarenessChanged();
 
     Q_INVOKABLE void setBugAwarenessPageData(bool, ReportInterface::Reproducible, bool, bool, bool);
@@ -127,10 +130,15 @@ public:
         return m_provideApplicationConfigurationDetails;
     }
 
+    bool isCrashEventSendingEnabled() const;
+    bool hasCrashEventSent() const;
+
 public Q_SLOTS:
-    void sendCrashEvent();
-    void sendCrashComment();
+    void prepareCrashEvent();
+    void prepareCrashComment();
     void sendBugReport();
+    void sendSentryReport();
+    void setSendWhenReady(bool send);
 
 private Q_SLOTS:
     void sendUsingDefaultProduct() const;
@@ -142,13 +150,17 @@ Q_SIGNALS:
     void done();
     void sendReportError(const QString &);
     void provideUnusualBehaviorChanged();
+    void crashEventSent();
 
 private:
+    explicit ReportInterface(QObject *parent = nullptr);
     // Attach backtrace to bug. Only used internally when the comment isn't
     // meant to be the full report.
     void attachBacktrace(const QString &comment);
     void sendToSentry();
     void maybeDone();
+    void maybePickUpPostbox();
+    void trySentry();
 
     QString generateAttachmentComment() const;
 
@@ -174,10 +186,12 @@ private:
     ProductMapping *m_productMapping = nullptr;
     BugzillaManager *m_bugzillaManager = nullptr;
 
-    SentryBeacon m_sentryBeacon;
-    bool m_sentryEventSent = false;
-    bool m_sentryUserFeedbackSent = false;
+    bool m_forceSentry = false;
+    QTimer m_sentryStartTimer;
+    bool m_tryingSentry = false;
+    SentryPostbox m_sentryPostbox;
     uint m_sentReport = 0;
+    bool m_sendWhenReady = false;
 };
 
 #endif
