@@ -26,7 +26,6 @@ public:
     static CrashedApplication *crashedApplication();
 
     static void saveReport(const QString &reportText, QWidget *parent = nullptr);
-    static void shutdownSaveReport();
     static void setSignal(int signal);
     static void setAppName(const QString &appName);
     static void setAppPath(const QString &appPath);
@@ -72,6 +71,9 @@ public:
     // that the user has seen the crash but chosen to ignore it (e.g. closed the dialog window)
     static void cleanupBeforeQuit();
 
+    // Whether to use the minimalistic UI or not. Defaults to false.
+    static bool minimalMode();
+
 private:
     DrKonqi();
     ~DrKonqi();
