@@ -39,6 +39,7 @@
 #include "qmlextensions/duplicatemodel.h"
 #include "qmlextensions/platformmodel.h"
 #include "qmlextensions/reproducibilitymodel.h"
+#include "settings.h"
 #include "systeminformation.h"
 
 static const QString ABOUT_BUG_REPORTING_URL = QStringLiteral("https://community.kde.org/Get_Involved/Issue_Reporting");
@@ -46,7 +47,7 @@ static const QString DRKONQI_REPORT_BUG_URL = KDE_BUGZILLA_URL + QStringLiteral(
 
 void DrKonqiDialog::show()
 {
-    if (DrKonqi::isSafer()) {
+    if (DrKonqi::isSafer() || DrKonqi::minimalMode()) {
         QDialog::show();
         return;
     }
@@ -61,16 +62,19 @@ void DrKonqiDialog::show()
     qmlRegisterType<DuplicateModel>("org.kde.drkonqi", 1, 0, "DuplicateModel");
     qmlRegisterType<PlatformModel>("org.kde.drkonqi", 1, 0, "PlatformModel");
     qmlRegisterType<ReproducibilityModel>("org.kde.drkonqi", 1, 0, "ReproducibilityModel");
-    qmlRegisterType<ReportInterface>("org.kde.drkonqi", 1, 0, "ReportInterface");
     qmlRegisterType<CredentialStore>("org.kde.drkonqi", 1, 0, "CredentialStore");
     qmlRegisterType<DebugPackageInstaller>("org.kde.drkonqi", 1, 0, "DebugPackageInstaller");
 
+    qmlRegisterSingletonInstance("org.kde.drkonqi", 1, 0, "ReportInterface", ReportInterface::self());
     qmlRegisterSingletonInstance("org.kde.drkonqi", 1, 0, "CrashedApplication", DrKonqi::crashedApplication());
     qmlRegisterSingletonInstance("org.kde.drkonqi", 1, 0, "BacktraceGenerator", DrKonqi::debuggerManager()->backtraceGenerator());
 
     static Doctore doctore;
     qmlRegisterSingletonInstance("org.kde.drkonqi", 1, 0, "DrKonqi", &doctore);
 
+    auto settings = Settings::self();
+    qmlRegisterSingletonInstance("org.kde.drkonqi", 1, 0, "Settings", settings);
+
     // TODO do we need this second BG?
     qmlRegisterUncreatableType<BacktraceGenerator>("org.kde.drkonqi", 1, 0, "BacktraceGenerator1", QStringLiteral("Cannot create WarningLevel in QML"));
     qmlRegisterUncreatableType<BacktraceParser>("org.kde.drkonqi", 1, 0, "BacktraceParser", QStringLiteral("Cannot create WarningLevel in QML"));
@@ -93,8 +97,8 @@ void DrKonqiDialog::show()
 DrKonqiDialog::DrKonqiDialog(QWidget *parent)
     : QDialog(parent)
 {
+    // NOTE: quitting the application is managed by main.cpp, do not ever call quit directly!
     setAttribute(Qt::WA_DeleteOnClose, true);
-    QGuiApplication::setQuitOnLastWindowClosed(true);
 
     // Setting dialog title and icon
     setWindowTitle(DrKonqi::crashedApplication()->name());
@@ -106,6 +110,7 @@ DrKonqiDialog::DrKonqiDialog(QWidget *parent)
     m_buttonBox = new QDialogButtonBox(this);
     connect(m_buttonBox, &QDialogButtonBox::accepted, this, &QDialog::accepted);
     connect(m_buttonBox, &QDialogButtonBox::rejected, this, &QDialog::rejected);
+    connect(m_buttonBox, &QDialogButtonBox::rejected, this, &QDialog::close);
     l->addWidget(m_buttonBox);
 
     connect(m_tabWidget, &QTabWidget::currentChanged, this, &DrKonqiDialog::tabIndexChanged);
@@ -339,3 +344,5 @@ void DrKonqiDialog::applicationRestarted(bool success)
 }
 
 #include "drkonqidialog.moc"
+
+#include "moc_drkonqidialog.cpp"
