@@ -7,10 +7,12 @@
  * SPDX-License-Identifier: BSD-2-Clause
  *****************************************************************/
 
+#include <chrono>
 #include <cstdlib>
 #include <unistd.h>
 
 #include <QIcon>
+#include <QTimer>
 
 #include <KAboutData>
 #include <KConfigGroup>
@@ -32,12 +34,14 @@
 #endif
 
 #include "backtracegenerator.h"
-#include "config-drkonqi.h"
+#include "bugzillaintegration/reportinterface.h"
 #include "debuggermanager.h"
 #include "drkonqi.h"
 #include "drkonqidialog.h"
 #include "statusnotifier.h"
 
+using namespace std::chrono_literals;
+
 static const char version[] = PROJECT_VERSION;
 
 namespace
@@ -50,11 +54,27 @@ void cleanupAfterUserQuit()
     qApp->quit();
 }
 
+void aboutToQuit()
+{
+    if (ReportInterface::self()->hasCrashEventSent()) {
+        cleanupAfterUserQuit();
+    } else {
+        // Add a fallback timer. This timer makes sure that drkonqi will definitely quit, even if it should
+        // have some sort of runtime defect that prevents reporting from finishing (and consequently not quitting).
+        static QTimer timer;
+        timer.setInterval(5min); // arbitrary time limit for trace+submission
+        QObject::connect(&timer, &QTimer::timeout, qApp, &cleanupAfterUserQuit);
+        QObject::connect(ReportInterface::self(), &ReportInterface::crashEventSent, qApp, &cleanupAfterUserQuit);
+        ReportInterface::self()->setSendWhenReady(true);
+        timer.start();
+    }
+}
+
 void openDrKonqiDialog()
 {
     auto *w = new DrKonqiDialog();
     QObject::connect(qApp, &QCoreApplication::aboutToQuit, w, &QObject::deleteLater);
-    QObject::connect(w, &DrKonqiDialog::rejected, qApp, &cleanupAfterUserQuit);
+    QObject::connect(qApp, &QGuiApplication::lastWindowClosed, qApp, &aboutToQuit);
     w->show();
 #ifdef Q_OS_MACOS
     KWindowSystem::forceActiveWindow(w->winId());
@@ -63,16 +83,24 @@ void openDrKonqiDialog()
 
 void requestDrKonqiDialog(bool restarted, bool interactionAllowed)
 {
+    auto activation = interactionAllowed ? StatusNotifier::Activation::Allowed : StatusNotifier::Activation::NotAllowed;
+    if (ReportInterface::self()->isCrashEventSendingEnabled()) {
+        activation = StatusNotifier::Activation::AlreadySubmitting;
+        ReportInterface::self()->setSendWhenReady(true);
+        if (DrKonqi::debuggerManager()->backtraceGenerator()->state() == BacktraceGenerator::NotLoaded) {
+            DrKonqi::debuggerManager()->backtraceGenerator()->start();
+        }
+    }
+
     auto *statusNotifier = new StatusNotifier();
-    statusNotifier->setActivationAllowed(interactionAllowed);
     if (interactionAllowed) {
         statusNotifier->show();
     }
     if (!restarted) {
-        statusNotifier->notify();
+        statusNotifier->notify(activation);
     }
-    QObject::connect(statusNotifier, &StatusNotifier::expired, qApp, &cleanupAfterUserQuit);
-    QObject::connect(statusNotifier, &StatusNotifier::activated, &openDrKonqiDialog);
+    QObject::connect(statusNotifier, &StatusNotifier::expired, qApp, &aboutToQuit);
+    QObject::connect(statusNotifier, &StatusNotifier::activated, qApp, &openDrKonqiDialog);
 }
 
 bool isShuttingDown()
@@ -98,10 +126,7 @@ int main(int argc, char *argv[])
 #endif
 
     QApplication app(argc, argv);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-#endif
-    KLocalizedString::setApplicationDomain("drkonqi5");
+    KLocalizedString::setApplicationDomain(QByteArrayLiteral("drkonqi5"));
 
     // Prevent KApplication from setting the crash handler. We will set it later...
     setenv("KDE_DEBUG", "true", 1);
@@ -109,9 +134,9 @@ int main(int argc, char *argv[])
     unsetenv("SESSION_MANAGER");
 
     KAboutData aboutData(QStringLiteral("drkonqi"),
-                         i18n("The KDE Crash Handler"),
+                         i18n("Crash Handler"),
                          QString::fromLatin1(version),
-                         i18n("The KDE Crash Handler gives the user feedback "
+                         i18n("Crash Handler gives the user feedback "
                               "if a program has crashed."),
                          KAboutLicense::GPL,
                          i18n("(C) 2000-2018, The DrKonqi Authors"));
@@ -203,6 +228,8 @@ int main(int argc, char *argv[])
     }
 
     app.setQuitOnLastWindowClosed(false);
+    // https://bugs.kde.org/show_bug.cgi?id=471941
+    app.setQuitLockEnabled(false);
 
     const bool restarted = parser.isSet(restartedOption);
 
@@ -210,20 +237,21 @@ int main(int argc, char *argv[])
     const bool interactionAllowed = KConfigGroup(KSharedConfig::openConfig(), "General").readEntry("InteractionAllowed", true);
     const bool shuttingDown = isShuttingDown();
 
-    // For automatically restarted services or during shutdown, do nothing in case no interaction is allowed
-    if (!forceDialog && !interactionAllowed && (restarted || shuttingDown)) {
-        return 0;
-    }
-
-    // if no notification service is running (eg. shell crashed, or other desktop environment)
-    // and we didn't auto-restart the app, open DrKonqi dialog instead of showing an SNI
-    // and emitting a desktop notification.
-    if (shuttingDown) {
-        DrKonqi::shutdownSaveReport();
-    } else if (forceDialog || (!restarted && !StatusNotifier::notificationServiceRegistered())) {
+    if (forceDialog) {
         openDrKonqiDialog();
+    } else if (shuttingDown) {
+        // this bypasses cleanupAfterUserQuit and consequently leaves the kcrash-metadata in place for later
+        // consumption via drkonqi-coredump-pickup
+        return 0;
     } else {
-        requestDrKonqiDialog(restarted, interactionAllowed);
+        // if no notification service is running (eg. shell crashed, or other desktop environment)
+        // and we didn't auto-restart the app, open DrKonqi dialog instead of showing an SNI
+        // and emitting a desktop notification.
+        if (!StatusNotifier::notificationServiceRegistered() && !restarted) {
+            openDrKonqiDialog();
+        } else { // StatusNotifierItem (interaction) or notification (no interaction)
+            requestDrKonqiDialog(restarted, interactionAllowed);
+        }
     }
 
     return app.exec();
